summaryrefslogtreecommitdiffstats
path: root/test/trefer.c
diff options
context:
space:
mode:
authorNeil Fortner <nfortne2@hdfgroup.org>2021-10-18 21:50:40 (GMT)
committerNeil Fortner <nfortne2@hdfgroup.org>2021-10-18 21:50:40 (GMT)
commit588f7f47da212a8a8077a4394ff740a4e8e537ee (patch)
tree8bb0dbb13d86f84067d3594ef07918e0fe73f4f6 /test/trefer.c
parent4c253cc332397a02cd172cb80d8d23d7161a485e (diff)
parent82b61574e1eb5f157d289185656eb877c3a33582 (diff)
downloadhdf5-588f7f47da212a8a8077a4394ff740a4e8e537ee.zip
hdf5-588f7f47da212a8a8077a4394ff740a4e8e537ee.tar.gz
hdf5-588f7f47da212a8a8077a4394ff740a4e8e537ee.tar.bz2
Merge branch 'hdf5_canon-develop' into selection_io
Diffstat (limited to 'test/trefer.c')
-rw-r--r--test/trefer.c14
1 files changed, 12 insertions, 2 deletions
diff --git a/test/trefer.c b/test/trefer.c
index 9b6c415..48d3670 100644
--- a/test/trefer.c
+++ b/test/trefer.c
@@ -3452,11 +3452,17 @@ test_reference_perf(void)
void
test_reference(void)
{
- H5F_libver_t low, high; /* Low and high bounds */
+ H5F_libver_t low, high; /* Low and high bounds */
+ const char * env_h5_drvr; /* File Driver value from environment */
/* Output message about test being performed */
MESSAGE(5, ("Testing References\n"));
+ /* Get the VFD to use */
+ env_h5_drvr = HDgetenv(HDF5_DRIVER);
+ if (env_h5_drvr == NULL)
+ env_h5_drvr = "nomatch";
+
test_reference_params(); /* Test for correct parameter checking */
test_reference_obj(); /* Test basic H5R object reference code */
test_reference_vlen_obj(); /* Test reference within vlen */
@@ -3476,7 +3482,11 @@ test_reference(void)
} /* end high bound */
} /* end low bound */
- test_reference_obj_deleted(); /* Test H5R object reference code for deleted objects */
+ /* The following test is currently broken with the Direct VFD */
+ if (HDstrcmp(env_h5_drvr, "direct") != 0) {
+ test_reference_obj_deleted(); /* Test H5R object reference code for deleted objects */
+ }
+
test_reference_group(); /* Test operations on dereferenced groups */
test_reference_attr(); /* Test attribute references */
test_reference_external(); /* Test external references */